@@ -1,5 +1,8 @@
 {
   en => {
+    attributes => {
+      state_id => "State",
+    },
     valiant => {
       models => { Authenticate => 'Sign In' }
     }
